import { IsString, IsEnum, Matches, IsOptional } from 'class-validator';

/**
 * DTO for updating an existing tag
 */
export class UpdateTagDto {
  /**
   * The name of the tag
   */
  @IsOptional()
  @IsString()
  name?: string;

  /**
   * The color of the tag (hex format)
   */
  @IsOptional()
  @IsString()
  @Matches(/^#[0-9A-Fa-f]{6}$/, {
    message: 'Color must be a valid hex color code (e.g., #FF5733)',
  })
  color?: string;

  /**
   * The type of the tag (PROJECT or PERSON)
   */
  @IsOptional()
  @IsEnum(['PROJECT', 'PERSON'], {
    message: 'Type must be either PROJECT or PERSON',
  })
  type?: 'PROJECT' | 'PERSON';
}